pub struct Parameters {
pub version: f32,
pub encryption: Option<ParameterEncryption>,
pub scenarios: Option<Vec<Scenario>>,
pub authorizations: Option<Vec<Authorization>>,
pub certificates: Option<Vec<Certificate>>,
pub proxies: Option<Vec<Proxy>>,
}Expand description
Stored parameters, authorization, client certificates and proxies stored outside of a workbook, either globally or alongside a workbook
Fields
version: f32Version of format (should not be changed manually)
encryption: Option<ParameterEncryption>Encryption
scenarios: Option<Vec<Scenario>>Scenarios
Authorizations
certificates: Option<Vec<Certificate>>Certificates
proxies: Option<Vec<Proxy>>Proxy servers
Implementations
Sourceimpl Parameters
impl Parameters
pub fn new( scenarios: Option<Vec<Scenario>>, authorizations: Option<Vec<Authorization>>, certificates: Option<Vec<Certificate>>, proxies: Option<Vec<Proxy>>, ) -> Self
Sourcepub fn open(
file_name: &PathBuf,
create_new_if_missing: bool,
) -> Result<Parameters, ApicizeError>
pub fn open( file_name: &PathBuf, create_new_if_missing: bool, ) -> Result<Parameters, ApicizeError>
Open parameters from parameters file; or, if specified, create default if parameters file does not exist
Sourcepub fn save(
&self,
file_name: &PathBuf,
destination_name: &str,
password: &Option<String>,
) -> Result<SerializationSaveSuccess, ApicizeError>
pub fn save( &self, file_name: &PathBuf, destination_name: &str, password: &Option<String>, ) -> Result<SerializationSaveSuccess, ApicizeError>
Save parametesr to file if it contains entries, otherwise, delete it
pub fn get_parameter_count(&self) -> usize
Sourcepub fn get_globals_filename() -> PathBuf
pub fn get_globals_filename() -> PathBuf
Return the file name for globals
Sourcepub fn get_workbook_private_filename(workbook_path: &Path) -> PathBuf
pub fn get_workbook_private_filename(workbook_path: &Path) -> PathBuf
Return the file name for a workbook’s private parameters file
Sourcepub fn any_encyrypted(&self) -> bool
pub fn any_encyrypted(&self) -> bool
Return true if any paramerers are encrypted
Sourcepub fn encyrpt(
&mut self,
password: &str,
method: ParameterEncryption,
) -> Result<Parameters, ApicizeError>
pub fn encyrpt( &mut self, password: &str, method: ParameterEncryption, ) -> Result<Parameters, ApicizeError>
Encrypt any plain entries