pub enum Scenario {
Cipher(ParameterCipher),
Plain(Box<ScenarioPlain>),
}Expand description
A set of variables that can be injected into templated values when submitting an Apicize Request that may be encrypted
Variants
Cipher(ParameterCipher)
Plain(Box<ScenarioPlain>)